# ApplyDiscountTo

Specifies the type of charges a specific discount applies to.   This field is only used when applied to a discount charge model. If you are not using a discount charge model, the value is null.  Possible values:  * `RECURRING` * `USAGE` * `ONETIMERECURRING` * `ONETIMEUSAGE` * `RECURRINGUSAGE` * `ONETIMERECURRINGUSAGE` 

## Enum

* `ONETIME` (value: `'ONETIME'`)

* `RECURRING` (value: `'RECURRING'`)

* `USAGE` (value: `'USAGE'`)

* `ONETIMERECURRING` (value: `'ONETIMERECURRING'`)

* `ONETIMEUSAGE` (value: `'ONETIMEUSAGE'`)

* `RECURRINGUSAGE` (value: `'RECURRINGUSAGE'`)

* `ONETIMERECURRINGUSAGE` (value: `'ONETIMERECURRINGUSAGE'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


